@@ -19,9 +19,17 @@ class IndexError(Error):
     """IndexError"""
 
 
+class KeyError(Error):
+    """KeyError"""
+
+
 class TypeError(Error):
     """TypeError"""
 
 
+class StopIteration(Error):
+    """StopIteration"""
+
+
 class UserError(Error):
     """UserError"""
