@@ -1,12 +1,11 @@
-import sys
 from copy import copy
 from collections import OrderedDict
 from inspect import getmembers, ismethod
 
 
 from mio import runtime
+from mio.utils import method, Null
 from mio.errors import AttributeError, TypeError
-from mio.utils import format_object, method, Null
 
 
 class Object(object):
@@ -231,7 +230,8 @@ class Object(object):
 
     @method("type", True)
     def getType(self, receiver, context, m):
-        return runtime.find("String").clone(receiver.type)
+        from mio.types import String
+        return String(receiver.type)
 
     @method("parent", True)
     def _parent(self, receiver, context, m):
@@ -245,9 +245,12 @@ class Object(object):
             return receiver.value
         return runtime.find("None")
 
-    @method(property=True)
+    @method("__hash__", property=True)
     def hash(self, receiver, context, m):
-        return runtime.find("Number").clone(hash(receiver))
+        try:
+            return runtime.find("Number").clone(hash(receiver))
+        except:
+            return runtime.find("None")
 
     @method(property=True)
     def id(self, receiver, context, m, obj=None):
@@ -260,16 +263,11 @@ class Object(object):
         keys = [String.clone(key) for key in receiver.attrs.keys()]
         return runtime.find("List").clone(keys)
 
-    @method(property=True)
-    def summary(self, receiver, context, m):
-        sys.stdout.write("%s\n" % format_object(receiver))
-        return receiver
-
     # Object Operations
 
     @method()
     def primitive(self, receiver, context, m, method, *args):
-        method = method.name
+        method = str(method.eval(context))
         args = [arg.eval(context).value for arg in args]
         if hasattr(receiver, method):
             return getattr(receiver, method)(*args)
