@@ -47,6 +47,17 @@ class String(Object):
         receiver.value = value or u""
         return receiver
 
+    # Special Methods
+
+    @method("__getitem__")
+    def getItem(self, receiver, context, m, i):
+        i = int(i.eval(context))
+        return receiver.value[i]
+
+    @method("__len__")
+    def getLen(self, receiver, context, m):
+        return runtime.find("Number").clone(len(receiver.value))
+
     # General Operations
 
     @method("+")
@@ -69,6 +80,13 @@ class String(Object):
         args = [str(arg.eval(context)) for arg in args]
         return receiver.clone(receiver.value.format(*args))
 
+    @method()
+    def split(self, receiver, context, m, sep=None, maxsplit=-1):
+        sep = runtime.state.frommio(sep.eval(context)) if sep is not None else sep
+        maxsplit = int(maxsplit.eval(context)) if maxsplit != -1 else maxsplit
+        xs = [runtime.types("String").clone(s) for s in receiver.value.split(sep, maxsplit)]
+        return runtime.types("List").clone(xs)
+
     @method()
     def join(self, receiver, context, m, *args):
         if len(args) == 1 and isinstance(args[0], Message):
