@@ -157,3 +157,8 @@ def test_grouping(mio):
 def test_parse(mio):
     chain = mio.eval("Parser parse(\"1 + 2\")")
     assert repr(chain) == "1 +(2)"
+
+
+def test_reshuffle(mio):
+    chain = parse(tokenize("x is not None"))
+    assert repr(chain) == "not(x is(None))"
