@@ -6,13 +6,13 @@ from mio.errors import AttributeError
 
 def test_basic_trait(mio, capfd):
     mio.eval("""
-        TGreeting = Object clone do (
+        TGreeting = Object clone() do (
             hello = method(
                 print("Hello", self getGreeting())
             )
         )
 
-        World = Object clone do (
+        World = Object clone() do (
             uses(TGreeting)
 
             greeting = "World!"
@@ -39,8 +39,8 @@ def test_basic_trait(mio, capfd):
 
 def test_hasTrait(mio):
     mio.eval("""
-        TGreetable = Object clone
-        World = Object clone do (
+        TGreetable = Object clone()
+        World = Object clone() do (
             uses(TGreetable)
         )
     """)
@@ -50,8 +50,8 @@ def test_hasTrait(mio):
 
 def test_delTrait(mio):
     mio.eval("""
-        TGreetable = Object clone
-        World = Object clone do (
+        TGreetable = Object clone()
+        World = Object clone() do (
             uses(TGreetable)
         )
     """)
@@ -64,13 +64,13 @@ def test_delTrait(mio):
 
 def test_delTrait2(mio, capfd):
     mio.eval("""
-        TGreetable = Object clone do (
+        TGreetable = Object clone() do (
             hello = method(
                 print("Hello World!")
             )
         )
 
-        World = Object clone do (
+        World = Object clone() do (
             uses(TGreetable)
         )
     """)
@@ -92,8 +92,8 @@ def test_delTrait2(mio, capfd):
 
 def test_addTrait(mio):
     mio.eval("""
-        TGreetable = Object clone
-        World = Object clone
+        TGreetable = Object clone()
+        World = Object clone()
     """)
 
     assert not mio.eval("World hasTrait(TGreetable)")
@@ -103,8 +103,8 @@ def test_addTrait(mio):
 
 def test_traits(mio):
     mio.eval("""
-        TGreetable = Object clone
-        World = Object clone do (
+        TGreetable = Object clone()
+        World = Object clone() do (
             uses(TGreetable)
         )
     """)
@@ -115,13 +115,13 @@ def test_traits(mio):
 
 def test_behaviors(mio, capfd):
     mio.eval("""
-        TGreetable = Object clone do (
+        TGreetable = Object clone() do (
             hello = method(
                 print("Hello World!")
             )
         )
 
-        World = Object clone do (
+        World = Object clone() do (
             uses(TGreetable)
         )
     """)
@@ -134,13 +134,13 @@ def test_behaviors(mio, capfd):
 
 def test_del_behavior(mio, capfd):
     mio.eval("""
-        TGreetable = Object clone do (
+        TGreetable = Object clone() do (
             hello = method(
                 print("Hello World!")
             )
         )
 
-        World = Object clone do (
+        World = Object clone() do (
             uses(TGreetable)
         )
     """)
