@@ -21,35 +21,35 @@ class Foo(Object):
 
 
 FOO_TEMPLATE = """Foo at {0:s}:
-  args            = args(a, b, c)
-  noargs          = noargs()
-  varargs         = varargs(*args)"""
+       args            = args(a, b, c)
+       noargs          = noargs()
+       varargs         = varargs(*args)"""
 
 
-def test_format_object():
+def test_format_object(mio):
     foo = Foo()
     assert format_object(foo) == FOO_TEMPLATE.format(hex(id(foo)))
 
 
-def test_format_method():
+def test_format_method(mio):
     foo = Foo()
     assert format_method(foo.noargs) == "noargs()"
     assert format_method(foo.args) == "args(a, b, c)"
     assert format_method(foo.varargs) == "varargs(*args)"
 
 
-def test_tryimport():
+def test_tryimport(mio):
     m = tryimport("sys")
     assert m is sys
 
 
-def test_tryimport_fail():
+def test_tryimport_fail(mio):
     try:
         tryimport("foo", "foo")
     except Warning as w:
         assert w[0] == "foo"
 
 
-def test_null():
+def test_null(mio):
     assert Null is Null
     assert Null() is Null
